/*****************************************************************************
  GLOBVW.CPP

  Purpose: CGlobalEditView implementation file.  CView derived object to contain
           CGlobalEdit object.

  Functions: CGlobalEditView::OnInitialUpdate()         Creates CGlobalEdit
             CGlobalEditView::Cut()                     Implements Cut option
             CGlobalEditView::Copy()                    Implements Copy option
             CGlobalEditView::Paste()                   Implements Pates option
             CGlobalEditView::CanUndo(CCmdUI* pCmdUI)   Determines whether Undo
                                                          should be grayed
             CGlobalEditView::OnUpdateEditPaste         Determines whether Paste
                                                          should be grayed
             CGlobalEditView::OnSize                    Resizes the edit control
                                                          to the view's size
                                                          
  Development Team: Jay Potter


  Written by Microsoft Product Support Services, Languages Developer Support
  Copyright (c) 1994 Microsoft Corporation. All rights reserved.
\****************************************************************************/

#include "stdafx.h"
#include "globedit.h"

#include "globdoc.h"
#include "globvw.h"

#ifdef _DEBUG
#undef THIS_FILE
static char BASED_CODE THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CGlobalEditView

IMPLEMENT_DYNCREATE(CGlobalEditView, CFormView)

BEGIN_MESSAGE_MAP(CGlobalEditView, CFormView)
    //{{AFX_MSG_MAP(CGlobalEditView)
    ON_WM_SIZE()
    //}}AFX_MSG_MAP
    // Standard printing commands
    ON_COMMAND(ID_EDIT_CUT, Cut)
    ON_COMMAND(ID_EDIT_COPY, Copy)
    ON_COMMAND(ID_EDIT_PASTE, Paste)
    ON_COMMAND(ID_EDIT_UNDO, Undo)
    ON_UPDATE_COMMAND_UI(ID_EDIT_UNDO, CanUndo)
    ON_UPDATE_COMMAND_UI(ID_EDIT_PASTE, OnUpdateEditPaste)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CGlobalEditView construction/destruction

CGlobalEditView::CGlobalEditView()
    : CFormView(CGlobalEditView::IDD)
{
    //{{AFX_DATA_INIT(CGlobalEditView)
        // NOTE: the ClassWizard will add member initialization here
    //}}AFX_DATA_INIT
    // TODO: add construction code here
}

CGlobalEditView::~CGlobalEditView()
{
}

void CGlobalEditView::DoDataExchange(CDataExchange* pDX)
{
    CFormView::DoDataExchange(pDX);
    //{{AFX_DATA_MAP(CGlobalEditView)
        // NOTE: the ClassWizard will add DDX and DDV calls here
    //}}AFX_DATA_MAP
}

/////////////////////////////////////////////////////////////////////////////
// CGlobalEditView printing

BOOL CGlobalEditView::OnPreparePrinting(CPrintInfo* pInfo)
{
    // default preparation
    return DoPreparePrinting(pInfo);
}

void CGlobalEditView::OnBeginPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
    // TODO: add extra initialization before printing
}

void CGlobalEditView::OnEndPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
    // TODO: add cleanup after printing
}

void CGlobalEditView::OnPrint(CDC* pDC, CPrintInfo*)
{
    // TODO: add code to print the controls
}

/////////////////////////////////////////////////////////////////////////////
// CGlobalEditView diagnostics

#ifdef _DEBUG
void CGlobalEditView::AssertValid() const
{
    CFormView::AssertValid();
}

void CGlobalEditView::Dump(CDumpContext& dc) const
{
    CFormView::Dump(dc);
}

CGlobalEditDoc* CGlobalEditView::GetDocument() // non-debug version is inline
{
    ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CGlobalEditDoc)));
    return (CGlobalEditDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CGlobalEditView message handlers

/************************************************************************
  CGlobalEditView::OnInitialUpdate()

  Purpose: Create the CGlobalEdit control to take up the entire client
           area and then set its text limit to 64K (65535).

  Parameters: none

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::OnInitialUpdate()
{
    // Call the base class
    CFormView::OnInitialUpdate();
    
    // Allocate an object to store the CGlobalEdit creation rect
    LPRECT lpRect = new __far RECT;
    
    // Initialize the CGlobalEdit creation rect to be as big as
    // the view
    GetClientRect(lpRect);
    
    // Create the CGlobalEdit and set the text limit to 65535 bytes
    // (see documentation on EM_LIMITTEXT, '0' sets the maximum
    // limit of 65535 bytes)
    m_cEdit.Create(0, CRect(lpRect), this, IDC_MYEDIT);
    m_cEdit.SendMessage(EM_LIMITTEXT, 0, 0L);
    
    delete lpRect;
}

/************************************************************************
  CGlobalEditView::Cut()

  Purpose: Calls the CEdit's implementation of Cut

  Parameters: none

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::Cut()
{
    m_cEdit.Cut();
}

/************************************************************************
  CGlobalEditView::Copy()

  Purpose: Calls the CEdit's implementation of Copy

  Parameters: none

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::Copy()
{
    m_cEdit.Copy();
}

/************************************************************************
  CGlobalEditView::Paste()

  Purpose: Calls the CEdit's implementation of Paste

  Parameters: none

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::Paste()
{
    m_cEdit.Paste();
}

/************************************************************************
  CGlobalEditView::Undo()

  Purpose: Calls the CEdit's implementation of Undo

  Parameters: none

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::Undo()
{
    m_cEdit.Undo();
}

/************************************************************************
  CGlobalEditView::CanUndo()

  Purpose: Determines whether Undo is available

  Parameters: CCmdUI* pCmdUI    Pointer to CmdUI object to update

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::CanUndo(CCmdUI* pCmdUI)
{
    pCmdUI->Enable(m_cEdit.CanUndo());
}

/************************************************************************
  CGlobalEditView::OnUpdateEditPaste

  Purpose: Determines whether Paste is available

  Parameters: CCmdUI* pCmdUI    Pointer to CmdUI object to update

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::OnUpdateEditPaste(CCmdUI* pCmdUI)
{
    OpenClipboard();
    
    // See if there is any text data available
    HANDLE hData = ::GetClipboardData(CF_TEXT);
    
    // Enable or disable based on whether there is
    pCmdUI->Enable((int)hData);
    CloseClipboard();   
}

/************************************************************************
  CGlobalEditView::OnSize()

  Purpose: Resizes the edit control to match the view

  Parameters: UINT  nType     Type of sizing
              int   cx        New width of client area
              int   cy        New height of client area

  Returns: none

  Comments:

  History:

  Date     Comment                                           Initials
  ======== ================================================= ========
  5/17/94  Created                                           OJP
\***********************************************************************/
void CGlobalEditView::OnSize(UINT nType, int cx, int cy)
{
    CFormView::OnSize(nType, cx, cy);
    
    // Create a RECT structure to store the new size
    LPRECT lpRect = new __far RECT;
    
    // Get the new client area size
    GetClientRect(lpRect);
    
    // Resize the edit control
    m_cEdit.MoveWindow(lpRect);
    
    delete lpRect;  
}
